**[Principe directeur]({{path '../../docs/documentation/design-principles.html'}})&nbsp;:** N’insérer que des éléments qui ont un rôle à jouer

## Directive générale sur les icônes

Les icônes sont une représentation **visuelle d’un objet, d’une action ou d’une idée simple et unique**. Si vous avez besoin de communiquer des concepts plus complexes, envisagez une illustration ou une infographie.

### Bibliothèque d’icônes du système de conception de l’Ontario 

La bibliothèque d’icônes du système de conception de l’Ontario est composée de deux ensembles&nbsp;:
- [icônes primaires]({{path './icons-primary.html'}})&nbsp;: cet ensemble représente les concepts les plus couramment utilisés dans le cadre de nos services (p. ex. téléphone, menu, recherche)
- [icônes secondaires]({{path './icons-secondary.html'}})&nbsp;: cet ensemble représente des concepts qui sont plus ou moins souvent utilisés (comme joindre, imprimer, épingler une carte)

#### Si vous avez besoin d’une icône différente

Si notre bibliothèque d’icônes ne contient pas le concept que vous devez représenter, vous pouvez choisir une icône dans le système Material Design de Google&nbsp;:
- [bibliothèque d’icônes](https://material.io/resources/icons/?style=baseline) (utilisez les versions remplies)
- [bibliothèque d’iconographie pilotée par la communauté](https://materialdesignicons.com/)

Toutes les fois que vous avez besoin d’une icône qui ne se trouve pas dans notre bibliothèque d’icônes, veuillez en informer [l’équipe du système de conception]({{path '../../docs/give-feedback.html'}}). Si nous constatons que les mêmes sont couramment utilisées, nous envisagerons de les ajouter à la bibliothèque.

<hr>

## Pourquoi choisissons-nous ces icônes?
Le système de conception de l’Ontario suit les principes de conception d’icônes du [système Material Design](https://material.io/design/iconography/system-icons.html) et utilise les icônes de la bibliothèque de  [Material Design](https://material.io/tools/icons/?style=baseline).

Nous avons choisi les icônes de notre bibliothèque en nous fondant sur les [meilleures pratiques](https://www.nngroup.com/articles/icon-usability/) qui ont fait leurs preuves, à savoir que toutes les icônes que nous utilisons doivent être&nbsp;:

- une représentation visuelle **d'un seul objet, d'une seule action ou d'une seule idée**
- faciles à **reconnaître et à comprendre**
- susceptibles d'être **interprétées de la même façon** par les utilisateurs
- utilisées pour représenter la «&nbsp;**reconnaissance universelle**&nbsp;» par opposition à la «&nbsp;représentation universelle&nbsp;»
  - par exemple, un fauteuil roulant est souvent utilisé pour l'accessibilité, même s'il ne représente pas tous les types de handicaps
- **pratiques**
  - les icônes doivent guider l'utilisateur dans l'accomplissement de sa tâche.  -- **n'utilisez pas les icônes dans un but purement visuel**.

<hr>

## Ensemble d’icônes primaires

Ces icônes représentent les concepts les plus couramment utilisés dans le cadre de nos services (p. ex. téléphone, menu, recherche).

<a href="#how-to-use-primary-icons">Passer à la partie Comment utiliser les icônes primaires.</a>

Toutes les icônes suivent le modèle de dénomination «&nbsp;ontario-icon-purpose&nbsp;». Vous pouvez rechercher des icônes particulières en utilisant la commande Rechercher de votre navigateur (`ctrl+f` sur un PC, `⌘+f` sur un Mac)

<a download href="{{path '../../icons/png/ontario-icons-archive-pngs.zip'}}">Télécharger toutes les icônes en format PNG</a>

<div class="fractal-table-scroll">

| Icône | Nom de l’icône | Usage ou alias | Téléchargement 
| ---------- | --------- | --------  | ------------------ 
|{{{render '@icons-primary--ontario-icon-accessibility' }}} | ontario-icon-accessibility| Accessibilité|<a download href="{{path '../../icons/png/ontario-icon-accessibility.png'}}">PNG</a> , <a target="_blank" href="{{path '../../icons/svg/ontario-icon-accessibility.svg'}}" download="ontario-icon-accessibility.svg">SVG</a>
|{{{render '@icons-primary--ontario-icon-add' }}} | ontario-icon-add| Ajouter une ligne, ajouter un champ|<a download href="{{path '../../icons/png/ontario-icon-add.png'}}">PNG</a> , <a target="_blank" href="{{path '../../icons/svg/ontario-icon-add.svg'}}" download="ontario-icon-add.svg">SVG</a>
|{{{render '@icons-primary--ontario-icon-add-alt' }}} | ontario-icon-add-alt| Ajouter une ligne, ajouter un champ|<a download href="{{path '../../icons/png/ontario-icon-add-alt.png'}}">PNG</a> , <a target="_blank" href="{{path '../../icons/svg/ontario-icon-add-alt.svg'}}" download="ontario-icon-add-alt.svg">SVG</a>
|{{{render '@icons-primary--ontario-icon-alert-error' }}} | ontario-icon-alert-error| Erreur, alerte, ! **Remarque**&nbsp;: La couleur doit être rouge Alerte (#CD0000)|<a download href="{{path '../../icons/png/ontario-icon-alert-error.png'}}">PNG</a> , <a target="_blank" href="{{path '../../icons/svg/ontario-icon-alert-error.svg'}}" download="ontario-icon-alert-error.svg">SVG</a>
|{{{render '@icons-primary--ontario-icon-alert-information' }}} | ontario-icon-alert-information| Information, i|<a download href="{{path '../../icons/png/ontario-icon-alert-information.png'}}">PNG</a> , <a target="_blank" href="{{path '../../icons/svg/ontario-icon-alert-information.svg'}}" download="ontario-icon-alert-information.svg">SVG</a>
|{{{render '@icons-primary--ontario-icon-alert-success' }}} | ontario-icon-alert-success| Réussite, confirmation. **Remarque**&nbsp;: La couleur doit être vert Réussite (#118847)|<a download href="{{path '../../icons/png/ontario-icon-alert-success.png'}}">PNG</a> , <a target="_blank" href="{{path '../../icons/svg/ontario-icon-alert-success.svg'}}" download="ontario-icon-alert-success.svg">SVG</a>
|{{{render '@icons-primary--ontario-icon-alert-warning' }}} | ontario-icon-alert-warning| Avertissement. **Remarque**&nbsp;: La couleur doit être jaune Avertissement  (#FCAF17)|<a download href="{{path '../../icons/png/ontario-icon-alert-warning.png'}}">PNG</a> , <a target="_blank" href="{{path '../../icons/svg/ontario-icon-alert-warning.svg'}}" download="ontario-icon-alert-warning.svg">SVG</a>
|{{{render '@icons-primary--ontario-icon-chevron-down' }}} | ontario-icon-chevron-down| Vers le bas|<a download href="{{path '../../icons/png/ontario-icon-chevron-down.png'}}">PNG</a> , <a target="_blank" href="{{path '../../icons/svg/ontario-icon-chevron-down.svg'}}" download="ontario-icon-chevron-down.svg">SVG</a>
|{{{render '@icons-primary--ontario-icon-chevron-left' }}} | ontario-icon-chevron-left| Gauche, retour|<a download href="{{path '../../icons/png/ontario-icon-chevron-left.png'}}">PNG</a> , <a target="_blank" href="{{path '../../icons/svg/ontario-icon-chevron-left.svg'}}" download="ontario-icon-chevron-left.svg">SVG</a>
|{{{render '@icons-primary--ontario-icon-chevron-right' }}} | ontario-icon-chevron-right| Droite, suivant|<a download href="{{path '../../icons/png/ontario-icon-chevron-right.png'}}">PNG</a> , <a target="_blank" href="{{path '../../icons/svg/ontario-icon-chevron-right.svg'}}" download="ontario-icon-chevron-right.svg">SVG</a>
|{{{render '@icons-primary--ontario-icon-chevron-up' }}} | ontario-icon-chevron-up| Vers le haut|<a download href="{{path '../../icons/png/ontario-icon-chevron-up.png'}}">PNG</a> , <a target="_blank" href="{{path '../../icons/svg/ontario-icon-chevron-up.svg'}}" download="ontario-icon-chevron-up.svg">SVG</a>
|{{{render '@icons-primary--ontario-icon-close' }}} | ontario-icon-close| Fermer, échapper|<a download href="{{path '../../icons/png/ontario-icon-close.png'}}">PNG</a> , <a target="_blank" href="{{path '../../icons/svg/ontario-icon-close.svg'}}" download="ontario-icon-close.svg">SVG</a>
|{{{render '@icons-primary--ontario-icon-collapse' }}} | ontario-icon-collapse| Fermer l’accordéon, réduire le champ|<a download href="{{path '../../icons/png/ontario-icon-collapse.png'}}">PNG</a> , <a target="_blank" href="{{path '../../icons/svg/ontario-icon-collapse.svg'}}" download="ontario-icon-collapse.svg">SVG</a>
|{{{render '@icons-primary--ontario-icon-credit-card' }}} | ontario-icon-credit-card| Paiement|<a download href="{{path '../../icons/png/ontario-icon-credit-card.png'}}">PNG</a> , <a target="_blank" href="{{path '../../icons/svg/ontario-icon-credit-card.svg'}}" download="ontario-icon-credit-card.svg">SVG</a>
|{{{render '@icons-primary--ontario-icon-dropdown-arrow' }}} | ontario-icon-dropdown-arrow| Dérouler, cocher une case, dérouler le menu, liste déroulante, liste de choix |<a download href="{{path '../../icons/png/ontario-icon-dropdown-arrow.png'}}">PNG</a> , <a target="_blank" href="{{path '../../icons/svg/ontario-icon-dropdown-arrow.svg'}}" download="ontario-icon-dropdown-arrow.svg">SVG</a>
|{{{render '@icons-primary--ontario-icon-email' }}} | ontario-icon-email| Courriel|<a download href="{{path '../../icons/png/ontario-icon-email.png'}}">PNG</a> , <a target="_blank" href="{{path '../../icons/svg/ontario-icon-email.svg'}}" download="ontario-icon-email.svg">SVG</a>
|{{{render '@icons-primary--ontario-icon-expand' }}} | ontario-icon-expand| Ouvrir l’accordéon, développer le champ|<a download href="{{path '../../icons/png/ontario-icon-expand.png'}}">PNG</a> , <a target="_blank" href="{{path '../../icons/svg/ontario-icon-expand.svg'}}" download="ontario-icon-expand.svg">SVG</a>
|{{{render '@icons-primary--ontario-icon-help' }}} | ontario-icon-help| Aide, ?, questions|<a download href="{{path '../../icons/png/ontario-icon-help.png'}}">PNG</a> , <a target="_blank" href="{{path '../../icons/svg/ontario-icon-help.svg'}}" download="ontario-icon-help.svg">SVG</a>
|{{{render '@icons-primary--ontario-icon-menu' }}} | ontario-icon-menu| Menu, menu Hamburger|<a download href="{{path '../../icons/png/ontario-icon-menu.png'}}">PNG</a> , <a target="_blank" href="{{path '../../icons/svg/ontario-icon-menu.svg'}}" download="ontario-icon-menu.svg">SVG</a>
|{{{render '@icons-primary--ontario-icon-new-window' }}} | ontario-icon-new-window| S’ouvre dans une nouvelle fenêtre|<a download href="{{path '../../icons/png/ontario-icon-new-window.png'}}">PNG</a> , <a target="_blank" href="{{path '../../icons/svg/ontario-icon-new-window.svg'}}" download="ontario-icon-new-window.svg">SVG</a>
|{{{render '@icons-primary--ontario-icon-phone' }}} | ontario-icon-phone| Téléphone, appeler|<a download href="{{path '../../icons/png/ontario-icon-phone.png'}}">PNG</a> , <a target="_blank" href="{{path '../../icons/svg/ontario-icon-phone.svg'}}" download="ontario-icon-phone.svg">SVG</a>
|{{{render '@icons-primary--ontario-icon-remove' }}} | ontario-icon-remove| Supprimer la ligne, supprimer le champ|<a download href="{{path '../../icons/png/ontario-icon-remove.png'}}">PNG</a> , <a target="_blank" href="{{path '../../icons/svg/ontario-icon-remove.svg'}}" download="ontario-icon-remove.svg">SVG</a>
|{{{render '@icons-primary--ontario-icon-remove-alt' }}} | ontario-icon-remove-alt| Supprimer la ligne, supprimer le champ|<a download href="{{path '../../icons/png/ontario-icon-remove-alt.png'}}">PNG</a> , <a target="_blank" href="{{path '../../icons/svg/ontario-icon-remove-alt.svg'}}" download="ontario-icon-remove-alt.svg">SVG</a>
|{{{render '@icons-primary--ontario-icon-search' }}} | ontario-icon-search| Trouver, rechercher|<a download href="{{path '../../icons/png/ontario-icon-search.png'}}">PNG</a> , <a target="_blank" href="{{path '../../icons/svg/ontario-icon-search.svg'}}" download="ontario-icon-search.svg">SVG</a>
|{{{render '@icons-primary--ontario-icon-tty' }}} | ontario-icon-tty| ATS|<a download href="{{path '../../icons/png/ontario-icon-tty.png'}}">PNG</a> , <a target="_blank" href="{{path '../../icons/svg/ontario-icon-tty.svg'}}" download="ontario-icon-tty.svg">SVG</a>

</div>

<hr>

## <a name="how-to-use-primary-icons"></a> Comment utiliser les icônes primaires

Copiez et collez le code  <abbr title="Scalable Vector Graphics">SVG</abbr> du fichier d’icônes primaires dans l’élément &lt;head&gt; de votre page HTML. Veuillez noter que vous devrez insérer le polyfill pour que les icônes s’affichent convenablement sur IE11. 

1. Insérez ce code en HTML (qui comprend les glyphes SVG) à votre page&nbsp;:

{{{render '@inline-code--icons-primary-setup' }}}

2.	Ajoutez ce code en HTML à l’endroit où vous voulez que l’icône apparaisse sur la page&nbsp;:

{{{render '@inline-code--icons-primary' }}}

3.	Ajoutez dans le fichier CSS de votre projet l’icône ontario-icon en forme CSS que vous trouverez sous l’onglet SCSS ou CSS compilé.  

    Vous trouverez des exemples sous l’onglet HTML.

<hr>

## Caractéristiques techniques (icônes primaires et secondaires)

<div class="fractal-table-scroll">

|Type de fichier |SVG |
| -----------| -----|
|Taille|Minimum `16 px`<br>Maximum H1 (`40 px` pour ordinateur, `32 px` pour appareils mobiles)|
|Taille de la correspondance| Si l’icône est cliquable, la zone de correspondance doit avoir au moins `48 px` sur `48 px` (voir Cases d’option pour un exemple où la taille de la correspondance est supérieure à celle de l’élément)<br><br>Si l’icône est une composante autonome, sa zone de correspondance doit être de `48 px` sur `48 px`. Si elle est cliquable et alignée avec le texte, elle doit avoir la même taille que la police.
|Couleur|Noir&nbsp;: `#1A1A1A`<br>Blanc&nbsp;:  `#FFFFFF`<br>Gris&nbsp;: `#666666`<br>Bleu (s’il y a un hyperlien)&nbsp;:<br> <ul><li>Régulier&nbsp;: `#0066CC`</li><li>Effet de survol&nbsp;:  `#004E99`</li><li>Visité&nbsp;: `#551A8B`</li></ul><br>Exceptions&nbsp;: certaines icônes viennent avec des couleurs déjà incorporées. Ne remplacez pas les couleurs des icônes qui sont déjà incorporées. Exemples&nbsp;:<br><ul><li>icônes d’alerte (rouge, vert et jaune)</li><li>icônes de Visa, Mastercard et Interac </li></ul>

</div>

<hr>

## Aidez-nous à améliorer cette page
Si vous avez d’autres suggestions, des conseils ou des questions sur les icônes, [l’équipe du système de conception]({{path '../../docs/give-feedback.html'}})  serait heureuse de les connaître.
