**[Guiding principle]({{path '../../docs/documentation/design-principles.html'}}):** Only include elements that have a purpose.

## General icon guidance

Icons are a visual representation of **a single and simple object, action or idea**. If you need to communicate more complicated concepts, consider an illustration or infographic. 

### The Ontario Design System icon library

The Ontario Design System icon library is made up of two sets:
- [Primary]({{path './icons-primary.html'}}) – these represent the most commonly used concepts on our services (such as phone, menu, search)
- [Secondary]({{path './icons-secondary.html'}}) – these represent concepts that are used often but not as frequently (such as attach, print, map pin)

#### If you need a different icon 

If the concept you need to represent isn’t already in our icon library, you can choose one from the Google Material Design:
- [icon library](https://material.io/resources/icons/?style=baseline) (use the filled versions)
- [community-led iconography library](https://materialdesignicons.com/)

Please let the [design system team]({{path '../../docs/give-feedback.html'}}) know any time you need an icon that isn’t in our icon library. If we find the same ones are being commonly used, we’ll consider adding them to the library.

<hr>

## Why we chose these icons
The Ontario Design System follows the [Material Design system icon design principles](https://material.io/design/iconography/system-icons.html) and uses icons from [Material Design’s icon library](https://material.io/tools/icons/?style=baseline).

We’ve chosen the icons for our library based on [proven best practices](https://www.nngroup.com/articles/icon-usability/) that all icons we use must be:
* a visual representation of **a single** object, action, or idea
* easily **recognizable and understandable**
* likely to be **interpreted in the same way** by users
* used to represent **“universal recognition”** as opposed to “universal representation”
    * for example, a wheelchair is often used for accessibility even though it does not represent all types of disabilities
* **useful**
    * icons should help guide the user to accomplish their task – **don’t use icons purely for visual interest**

<hr>

## Secondary icon set
These icons represent concepts that are used often but not as frequently as ones in the primary set (such as attach, print, map pin).

<a href="#how-to-use-secondary-icons">Skip to how to use secondary icons.</a>

All icons follow the naming pattern "ontario-icon-purpose". You can search for specific icons using your browser’s find command (`ctrl+f` for PC, `⌘+f` for Mac)

<a download href="{{path '../../icons/png/ontario-icons-archive-pngs.zip'}}">Download all icons as PNG</a>

### Secondary icon categories

We’ve organized the secondary icons into these categories:

- [Accounts and web applications](#1)
- [Interactions](#2)
- [Multimedia](#3)
- [Communication and social media](#4)
- [Payment](#5)
- [Maps and transportation](#6)
- [Feedback](#7)

#### <a name="1"></a>Accounts and web applications

<div class="fractal-table-scroll">

|Icon |Icon name |Purpose or aliases |Download |
| ------| -----| ----------------------| -----|
|{{{render '@icons-secondary--ontario-icon-account' }}} | ontario-icon-account| |<a download href="{{path '../../icons/png/ontario-icon-account.png'}}">PNG</a> , <a target="_blank" href="{{path '../../icons/svg/ontario-icon-account.svg'}}" download="ontario-icon-account.svg">SVG</a>
|{{{render '@icons-secondary--ontario-icon-bookmark-off' }}} | ontario-icon-bookmark-off| Favourite, save|<a download href="{{path '../../icons/png/ontario-icon-bookmark-off.png'}}">PNG</a> , <a target="_blank" href="{{path '../../icons/svg/ontario-icon-bookmark-off.svg'}}" download="ontario-icon-bookmark-off.svg">SVG</a>
|{{{render '@icons-secondary--ontario-icon-bookmark-on' }}} | ontario-icon-bookmark-on| Favourite, save|<a download href="{{path '../../icons/png/ontario-icon-bookmark-on.png'}}">PNG</a> , <a target="_blank" href="{{path '../../icons/svg/ontario-icon-bookmark-on.svg'}}" download="ontario-icon-bookmark-on.svg">SVG</a>
|{{{render '@icons-secondary--ontario-icon-cloud' }}} | ontario-icon-cloud| |<a download href="{{path '../../icons/png/ontario-icon-cloud.png'}}">PNG</a> , <a target="_blank" href="{{path '../../icons/svg/ontario-icon-cloud.svg'}}" download="ontario-icon-cloud.svg">SVG</a>
|{{{render '@icons-secondary--ontario-icon-more-vertical' }}} | ontario-icon-more-vertical| |<a download href="{{path '../../icons/png/ontario-icon-more-vertical.png'}}">PNG</a> , <a target="_blank" href="{{path '../../icons/svg/ontario-icon-more-vertical.svg'}}" download="ontario-icon-more-vertical.svg">SVG</a>
|{{{render '@icons-secondary--ontario-icon-notification' }}} | ontario-icon-notification| Alert|<a download href="{{path '../../icons/png/ontario-icon-notification.png'}}">PNG</a> , <a target="_blank" href="{{path '../../icons/svg/ontario-icon-notification.svg'}}" download="ontario-icon-notification.svg">SVG</a>
|{{{render '@icons-secondary--ontario-icon-password-hide' }}} | ontario-icon-password-hide| |<a download href="{{path '../../icons/png/ontario-icon-password-hide.png'}}">PNG</a> , <a target="_blank" href="{{path '../../icons/svg/ontario-icon-password-hide.svg'}}" download="ontario-icon-password-hide.svg">SVG</a>
|{{{render '@icons-secondary--ontario-icon-password-show' }}} | ontario-icon-password-show| |<a download href="{{path '../../icons/png/ontario-icon-password-show.png'}}">PNG</a> , <a target="_blank" href="{{path '../../icons/svg/ontario-icon-password-show.svg'}}" download="ontario-icon-password-show.svg">SVG</a>
|{{{render '@icons-secondary--ontario-icon-settings' }}} | ontario-icon-settings| |<a download href="{{path '../../icons/png/ontario-icon-settings.png'}}">PNG</a> , <a target="_blank" href="{{path '../../icons/svg/ontario-icon-settings.svg'}}" download="ontario-icon-settings.svg">SVG</a>
|{{{render '@icons-secondary--ontario-icon-tag' }}} | ontario-icon-tag| |<a download href="{{path '../../icons/png/ontario-icon-tag.png'}}">PNG</a> , <a target="_blank" href="{{path '../../icons/svg/ontario-icon-tag.svg'}}" download="ontario-icon-tag.svg">SVG</a>

</div>

<br>

#### <a name="2"></a>Interactions

<div class="fractal-table-scroll">

|Icon |Icon name |Purpose or aliases |Download |
| ------| -----| ----------------------| -----|
|{{{render '@icons-secondary--ontario-icon-attach' }}} | ontario-icon-attach| Attachment, file|<a download href="{{path '../../icons/png/ontario-icon-attach.png'}}">PNG</a> , <a target="_blank" href="{{path '../../icons/svg/ontario-icon-attach.svg'}}" download="ontario-icon-attach.svg">SVG</a>
|{{{render '@icons-secondary--ontario-icon-calendar' }}} | ontario-icon-calendar| Date, date picker|<a download href="{{path '../../icons/png/ontario-icon-calendar.png'}}">PNG</a> , <a target="_blank" href="{{path '../../icons/svg/ontario-icon-calendar.svg'}}" download="ontario-icon-calendar.svg">SVG</a>
|{{{render '@icons-secondary--ontario-icon-clock' }}} | ontario-icon-clock| Time, schedule|<a download href="{{path '../../icons/png/ontario-icon-clock.png'}}">PNG</a> , <a target="_blank" href="{{path '../../icons/svg/ontario-icon-clock.svg'}}" download="ontario-icon-clock.svg">SVG</a>
|{{{render '@icons-secondary--ontario-icon-delete' }}} | ontario-icon-delete| Delete, remove|<a download href="{{path '../../icons/png/ontario-icon-delete.png'}}">PNG</a> , <a target="_blank" href="{{path '../../icons/svg/ontario-icon-delete.svg'}}" download="ontario-icon-delete.svg">SVG</a>
|{{{render '@icons-secondary--ontario-icon-document' }}} | ontario-icon-document| Attach, file type, file|<a download href="{{path '../../icons/png/ontario-icon-document.png'}}">PNG</a> , <a target="_blank" href="{{path '../../icons/svg/ontario-icon-document.svg'}}" download="ontario-icon-document.svg">SVG</a>
|{{{render '@icons-secondary--ontario-icon-download' }}} | ontario-icon-download| |<a download href="{{path '../../icons/png/ontario-icon-download.png'}}">PNG</a> , <a target="_blank" href="{{path '../../icons/svg/ontario-icon-download.svg'}}" download="ontario-icon-download.svg">SVG</a>
|{{{render '@icons-secondary--ontario-icon-edit' }}} | ontario-icon-edit| |<a download href="{{path '../../icons/png/ontario-icon-edit.png'}}">PNG</a> , <a target="_blank" href="{{path '../../icons/svg/ontario-icon-edit.svg'}}" download="ontario-icon-edit.svg">SVG</a>
|{{{render '@icons-secondary--ontario-icon-export' }}} | ontario-icon-export| |<a download href="{{path '../../icons/png/ontario-icon-export.png'}}">PNG</a> , <a target="_blank" href="{{path '../../icons/svg/ontario-icon-export.svg'}}" download="ontario-icon-export.svg">SVG</a>
|{{{render '@icons-secondary--ontario-icon-favourite-off' }}} | ontario-icon-favourite-off| Like, save, heart|<a download href="{{path '../../icons/png/ontario-icon-favourite-off.png'}}">PNG</a> , <a target="_blank" href="{{path '../../icons/svg/ontario-icon-favourite-off.svg'}}" download="ontario-icon-favourite-off.svg">SVG</a>
|{{{render '@icons-secondary--ontario-icon-favourite-on' }}} | ontario-icon-favourite-on| Like, save, heart|<a download href="{{path '../../icons/png/ontario-icon-favourite-on.png'}}">PNG</a> , <a target="_blank" href="{{path '../../icons/svg/ontario-icon-favourite-on.svg'}}" download="ontario-icon-favourite-on.svg">SVG</a>
|{{{render '@icons-secondary--ontario-icon-filter' }}} | ontario-icon-filter| Filter|<a download href="{{path '../../icons/png/ontario-icon-filter.png'}}">PNG</a> , <a target="_blank" href="{{path '../../icons/svg/ontario-icon-filter.svg'}}" download="ontario-icon-filter.svg">SVG</a>
|{{{render '@icons-secondary--ontario-icon-grid' }}} | ontario-icon-grid| Change view|<a download href="{{path '../../icons/png/ontario-icon-grid.png'}}">PNG</a> , <a target="_blank" href="{{path '../../icons/svg/ontario-icon-grid.svg'}}" download="ontario-icon-grid.svg">SVG</a>
|{{{render '@icons-secondary--ontario-icon-list' }}} | ontario-icon-list| Change view|<a download href="{{path '../../icons/png/ontario-icon-list.png'}}">PNG</a> , <a target="_blank" href="{{path '../../icons/svg/ontario-icon-list.svg'}}" download="ontario-icon-list.svg">SVG</a>
|{{{render '@icons-secondary--ontario-icon-location-off' }}} | ontario-icon-location-off| Turn off location, gps|<a download href="{{path '../../icons/png/ontario-icon-location-off.png'}}">PNG</a> , <a target="_blank" href="{{path '../../icons/svg/ontario-icon-location-off.svg'}}" download="ontario-icon-location-off.svg">SVG</a>
|{{{render '@icons-secondary--ontario-icon-location-on' }}} | ontario-icon-location-on| Find location, gps|<a download href="{{path '../../icons/png/ontario-icon-location-on.png'}}">PNG</a> , <a target="_blank" href="{{path '../../icons/svg/ontario-icon-location-on.svg'}}" download="ontario-icon-location-on.svg">SVG</a>
|{{{render '@icons-secondary--ontario-icon-lock-on' }}} | ontario-icon-lock-on| Safe, password|<a download href="{{path '../../icons/png/ontario-icon-lock-on.png'}}">PNG</a> , <a target="_blank" href="{{path '../../icons/svg/ontario-icon-lock-on.svg'}}" download="ontario-icon-lock-on.svg">SVG</a>
|{{{render '@icons-secondary--ontario-icon-lock-off' }}} | ontario-icon-lock-off| Safe, password|<a download href="{{path '../../icons/png/ontario-icon-lock-off.png'}}">PNG</a> , <a target="_blank" href="{{path '../../icons/svg/ontario-icon-lock-off.svg'}}" download="ontario-icon-lock-off.svg">SVG</a>
|{{{render '@icons-secondary--ontario-icon-next' }}} | ontario-icon-next| |<a download href="{{path '../../icons/png/ontario-icon-next.png'}}">PNG</a> , <a target="_blank" href="{{path '../../icons/svg/ontario-icon-next.svg'}}" download="ontario-icon-next.svg">SVG</a>
|{{{render '@icons-secondary--ontario-icon-pin-location-off' }}} | ontario-icon-pin-location-off| Find location|<a download href="{{path '../../icons/png/ontario-icon-pin-location-off.png'}}">PNG</a> , <a target="_blank" href="{{path '../../icons/svg/ontario-icon-pin-location-off.svg'}}" download="ontario-icon-pin-location-off.svg">SVG</a>
|{{{render '@icons-secondary--ontario-icon-pin-location-on' }}} | ontario-icon-pin-location-on| Find location|<a download href="{{path '../../icons/png/ontario-icon-pin-location-on.png'}}">PNG</a> , <a target="_blank" href="{{path '../../icons/svg/ontario-icon-pin-location-on.svg'}}" download="ontario-icon-pin-location-on.svg">SVG</a>
|{{{render '@icons-secondary--ontario-icon-previous' }}} | ontario-icon-previous| |<a download href="{{path '../../icons/png/ontario-icon-previous.png'}}">PNG</a> , <a target="_blank" href="{{path '../../icons/svg/ontario-icon-previous.svg'}}" download="ontario-icon-previous.svg">SVG</a>
|{{{render '@icons-secondary--ontario-icon-print' }}} | ontario-icon-print| Print|<a download href="{{path '../../icons/png/ontario-icon-print.png'}}">PNG</a> , <a target="_blank" href="{{path '../../icons/svg/ontario-icon-print.svg'}}" download="ontario-icon-print.svg">SVG</a>
|{{{render '@icons-secondary--ontario-icon-save' }}} | ontario-icon-save| Save|<a download href="{{path '../../icons/png/ontario-icon-save.png'}}">PNG</a> , <a target="_blank" href="{{path '../../icons/svg/ontario-icon-save.svg'}}" download="ontario-icon-save.svg">SVG</a>
|{{{render '@icons-secondary--ontario-icon-sort' }}} | ontario-icon-sort| Sort|<a download href="{{path '../../icons/png/ontario-icon-sort.png'}}">PNG</a> , <a target="_blank" href="{{path '../../icons/svg/ontario-icon-sort.svg'}}" download="ontario-icon-sort.svg">SVG</a>
|{{{render '@icons-secondary--ontario-icon-timer' }}} | ontario-icon-timer| Stopwatch|<a download href="{{path '../../icons/png/ontario-icon-timer.png'}}">PNG</a> , <a target="_blank" href="{{path '../../icons/svg/ontario-icon-timer.svg'}}" download="ontario-icon-timer.svg">SVG</a>
|{{{render '@icons-secondary--ontario-icon-upload' }}} | ontario-icon-upload| |<a download href="{{path '../../icons/png/ontario-icon-upload.png'}}">PNG</a> , <a target="_blank" href="{{path '../../icons/svg/ontario-icon-upload.svg'}}" download="ontario-icon-upload.svg">SVG</a>
|{{{render '@icons-secondary--ontario-icon-vpn-key' }}} | ontario-icon-vpn-key| |<a download href="{{path '../../icons/png/ontario-icon-vpn-key.png'}}">PNG</a> , <a target="_blank" href="{{path '../../icons/svg/ontario-icon-vpn-key.svg'}}" download="ontario-icon-vpn-key.svg">SVG</a>

</div>

<br>

#### <a name="3"></a>Multimedia

<div class="fractal-table-scroll">

|Icon |Icon name |Purpose or aliases |Download |
| ------| -----| ----------------------| -----|
|{{{render '@icons-secondary--ontario-icon-camera' }}} | ontario-icon-camera| |<a download href="{{path '../../icons/png/ontario-icon-camera.png'}}">PNG</a> , <a target="_blank" href="{{path '../../icons/svg/ontario-icon-camera.svg'}}" download="ontario-icon-camera.svg">SVG</a>
|{{{render '@icons-secondary--ontario-icon-media-fast-forward' }}} | ontario-icon-media-fast-forward| Speed up|<a download href="{{path '../../icons/png/ontario-icon-media-fast-forward.png'}}">PNG</a> , <a target="_blank" href="{{path '../../icons/svg/ontario-icon-media-fast-forward.svg'}}" download="ontario-icon-media-fast-forward.svg">SVG</a>
|{{{render '@icons-secondary--ontario-icon-media-fast-rewind' }}} | ontario-icon-media-fast-rewind| Back|<a download href="{{path '../../icons/png/ontario-icon-media-fast-rewind.png'}}">PNG</a> , <a target="_blank" href="{{path '../../icons/svg/ontario-icon-media-fast-rewind.svg'}}" download="ontario-icon-media-fast-rewind.svg">SVG</a>
|{{{render '@icons-secondary--ontario-icon-media-pause' }}} | ontario-icon-media-pause| |<a download href="{{path '../../icons/png/ontario-icon-media-pause.png'}}">PNG</a> , <a target="_blank" href="{{path '../../icons/svg/ontario-icon-media-pause.svg'}}" download="ontario-icon-media-pause.svg">SVG</a>
|{{{render '@icons-secondary--ontario-icon-media-play' }}} | ontario-icon-media-play| |<a download href="{{path '../../icons/png/ontario-icon-media-play.png'}}">PNG</a> , <a target="_blank" href="{{path '../../icons/svg/ontario-icon-media-play.svg'}}" download="ontario-icon-media-play.svg">SVG</a>
|{{{render '@icons-secondary--ontario-icon-media-stop' }}} | ontario-icon-media-stop| |<a download href="{{path '../../icons/png/ontario-icon-media-stop.png'}}">PNG</a> , <a target="_blank" href="{{path '../../icons/svg/ontario-icon-media-stop.svg'}}" download="ontario-icon-media-stop.svg">SVG</a>
|{{{render '@icons-secondary--ontario-icon-microphone-off' }}} | ontario-icon-microphone-off| Record|<a download href="{{path '../../icons/png/ontario-icon-microphone-off.png'}}">PNG</a> , <a target="_blank" href="{{path '../../icons/svg/ontario-icon-microphone-off.svg'}}" download="ontario-icon-microphone-off.svg">SVG</a>
|{{{render '@icons-secondary--ontario-icon-microphone-on' }}} | ontario-icon-microphone-on| Record|<a download href="{{path '../../icons/png/ontario-icon-microphone-on.png'}}">PNG</a> , <a target="_blank" href="{{path '../../icons/svg/ontario-icon-microphone-on.svg'}}" download="ontario-icon-microphone-on.svg">SVG</a>
|{{{render '@icons-secondary--ontario-icon-photo' }}} | ontario-icon-photo| |<a download href="{{path '../../icons/png/ontario-icon-photo.png'}}">PNG</a> , <a target="_blank" href="{{path '../../icons/svg/ontario-icon-photo.svg'}}" download="ontario-icon-photo.svg">SVG</a>
|{{{render '@icons-secondary--ontario-icon-replay' }}} | ontario-icon-replay| |<a download href="{{path '../../icons/png/ontario-icon-replay.png'}}">PNG</a> , <a target="_blank" href="{{path '../../icons/svg/ontario-icon-replay.svg'}}" download="ontario-icon-replay.svg">SVG</a>
|{{{render '@icons-secondary--ontario-icon-video' }}} | ontario-icon-video| |<a download href="{{path '../../icons/png/ontario-icon-video.png'}}">PNG</a> , <a target="_blank" href="{{path '../../icons/svg/ontario-icon-video.svg'}}" download="ontario-icon-video.svg">SVG</a>
|{{{render '@icons-secondary--ontario-icon-wifi' }}} | ontario-icon-wifi| |<a download href="{{path '../../icons/png/ontario-icon-wifi.png'}}">PNG</a> , <a target="_blank" href="{{path '../../icons/svg/ontario-icon-wifi.svg'}}" download="ontario-icon-wifi.svg">SVG</a>

</div>

<br>

#### <a name="4"></a>Communication and social media

<div class="fractal-table-scroll">

|Icon |Icon name |Purpose or aliases |Download |
| ------| -----|------  |-----|
|{{{render '@icons-secondary--ontario-icon-facebook'}}} | ontario-icon-facebook| |<a download href="{{path '../../icons/png/ontario-icon-facebook.png'}}">PNG</a> , <a target="_blank" href="{{path '../../icons/svg/ontario-icon-facebook.svg'}}" download="ontario-icon-facebook.svg">SVG</a>
|{{{render '@icons-secondary--ontario-icon-facebook-alt'}}} | ontario-icon-facebook-alt| |<a download href="{{path '../../icons/png/ontario-icon-facebook-alt.png'}}">PNG</a> , <a target="_blank" href="{{path '../../icons/svg/ontario-icon-facebook-alt.svg'}}" download="ontario-icon-facebook-alt.svg">SVG</a>
|{{{render '@icons-secondary--ontario-icon-flickr'}}} | ontario-icon-flickr| |<a download href="{{path '../../icons/png/ontario-icon-flickr.png'}}">PNG</a> , <a target="_blank" href="{{path '../../icons/svg/ontario-icon-flickr.svg'}}" download="ontario-icon-flickr.svg">SVG</a>
|{{{render '@icons-secondary--ontario-icon-instagram'}}} | ontario-icon-instagram| |<a download href="{{path '../../icons/png/ontario-icon-instagram.png'}}">PNG</a> , <a target="_blank" href="{{path '../../icons/svg/ontario-icon-instagram.svg'}}" download="ontario-icon-instagram.svg">SVG</a>
|{{{render '@icons-secondary--ontario-icon-linkedin'}}} | ontario-icon-linkedin| |<a download href="{{path '../../icons/png/ontario-icon-linkedin.png'}}">PNG</a> , <a target="_blank" href="{{path '../../icons/svg/ontario-icon-linkedin.svg'}}" download="ontario-icon-linkedin.svg">SVG</a>
|{{{render '@icons-secondary--ontario-icon-linkedin-alt'}}} | ontario-icon-linkedin-alt| |<a download href="{{path '../../icons/png/ontario-icon-linkedin-alt.png'}}">PNG</a> , <a target="_blank" href="{{path '../../icons/svg/ontario-icon-linkedin-alt.svg'}}" download="ontario-icon-linkedin-alt.svg">SVG</a>
|{{{render '@icons-secondary--ontario-icon-live-chat'}}} | ontario-icon-live-chat| |<a download href="{{path '../../icons/png/ontario-icon-live-chat.png'}}">PNG</a> , <a target="_blank" href="{{path '../../icons/svg/ontario-icon-live-chat.svg'}}" download="ontario-icon-live-chat.svg">SVG</a>
|{{{render '@icons-secondary--ontario-icon-rss-feed'}}} | ontario-icon-rss-feed| |<a download href="{{path '../../icons/png/ontario-icon-rss-feed.png'}}">PNG</a> , <a target="_blank" href="{{path '../../icons/svg/ontario-icon-rss-feed.svg'}}" download="ontario-icon-rss-feed.svg">SVG</a>
|{{{render '@icons-secondary--ontario-icon-share'}}} | ontario-icon-share| |<a download href="{{path '../../icons/png/ontario-icon-share.png'}}">PNG</a> , <a target="_blank" href="{{path '../../icons/svg/ontario-icon-share.svg'}}" download="ontario-icon-share.svg">SVG</a>
|{{{render '@icons-secondary--ontario-icon-text-message'}}} | ontario-icon-text-message| sms, text message|<a download href="{{path '../../icons/png/ontario-icon-text-message.png'}}">PNG</a> , <a target="_blank" href="{{path '../../icons/svg/ontario-icon-text-message.svg'}}" download="ontario-icon-text-message.svg">SVG</a>
|{{{render '@icons-secondary--ontario-icon-twitter'}}} | ontario-icon-twitter| |<a download href="{{path '../../icons/png/ontario-icon-twitter.png'}}">PNG</a> , <a target="_blank" href="{{path '../../icons/svg/ontario-icon-twitter.svg'}}" download="ontario-icon-twitter.svg">SVG</a>
|{{{render '@icons-secondary--ontario-icon-twitter-alt'}}} | ontario-icon-twitter-alt| |<a download href="{{path '../../icons/png/ontario-icon-twitter-alt.png'}}">PNG</a> , <a target="_blank" href="{{path '../../icons/svg/ontario-icon-twitter-alt.svg'}}" download="ontario-icon-twitter-alt.svg">SVG</a>
|{{{render '@icons-secondary--ontario-icon-youtube'}}} | ontario-icon-youtube| |<a download href="{{path '../../icons/png/ontario-icon-youtube.png'}}">PNG</a> , <a target="_blank" href="{{path '../../icons/svg/ontario-icon-youtube.svg'}}" download="ontario-icon-youtube.svg">SVG</a>

</div>

<br>

#### <a name="5"></a>Payment

<div class="fractal-table-scroll">

|Icon |Icon name |Download |
| ------| -----|-----|
|{{{render '@icons-secondary--ontario-icon-interac-en' }}} | ontario-icon-interac-en| <a download href="{{path '../../icons/png/ontario-icon-interac-en.png'}}">PNG</a> , <a target="_blank" href="{{path '../../icons/svg/ontario-icon-interac-en.svg'}}" download="ontario-icon-interac-en.svg">SVG</a>
|{{{render '@icons-secondary--ontario-icon-interac-fr' }}} | ontario-icon-interac-fr| <a download href="{{path '../../icons/png/ontario-icon-interac-fr.png'}}">PNG</a> , <a target="_blank" href="{{path '../../icons/svg/ontario-icon-interac-fr.svg'}}" download="ontario-icon-interac-fr.svg">SVG</a>
|{{{render '@icons-secondary--ontario-icon-interac-en-alt' }}} | ontario-icon-interac-en-alt| <a download href="{{path '../../icons/png/ontario-icon-interac-en-alt.png'}}">PNG</a> , <a target="_blank" href="{{path '../../icons/svg/ontario-icon-interac-en-alt.svg'}}" download="ontario-icon-interac-en-alt.svg">SVG</a>
|{{{render '@icons-secondary--ontario-icon-interac-fr-alt' }}} | ontario-icon-interac-fr-alt| <a download href="{{path '../../icons/png/ontario-icon-interac-fr-alt.png'}}">PNG</a> , <a target="_blank" href="{{path '../../icons/svg/ontario-icon-interac-fr-alt.svg'}}" download="ontario-icon-interac-fr-alt.svg">SVG</a>
|{{{render '@icons-secondary--ontario-icon-mastercard' }}} | ontario-icon-mastercard| <a download href="{{path '../../icons/png/ontario-icon-mastercard.png'}}">PNG</a> , <a target="_blank" href="{{path '../../icons/svg/ontario-icon-mastercard.svg'}}" download="ontario-icon-mastercard.svg">SVG</a>
|{{{render '@icons-secondary--ontario-icon-mastercard-alt' }}} | ontario-icon-mastercard-alt| <a download href="{{path '../../icons/png/ontario-icon-mastercard-alt.png'}}">PNG</a> , <a target="_blank" href="{{path '../../icons/svg/ontario-icon-mastercard-alt.svg'}}" download="ontario-icon-mastercard-alt.svg">SVG</a>
|{{{render '@icons-secondary--ontario-icon-visa' }}} | ontario-icon-visa| <a download href="{{path '../../icons/png/ontario-icon-visa.png'}}">PNG</a> , <a target="_blank" href="{{path '../../icons/svg/ontario-icon-visa.svg'}}" download="ontario-icon-visa.svg">SVG</a>

</div>

<br>

#### <a name="6"></a>Maps and transportation

<div class="fractal-table-scroll">

|Icon |Icon name |Download |
| ------| -----|---------|
|{{{render '@icons-secondary--ontario-icon-map' }}} | ontario-icon-map| <a download href="{{path '../../icons/png/ontario-icon-map.png'}}">PNG</a> , <a target="_blank" href="{{path '../../icons/svg/ontario-icon-map.svg'}}" download="ontario-icon-map.svg">SVG</a>
|{{{render '@icons-secondary--ontario-icon-transport-bicycle' }}} | ontario-icon-transport-bicycle| <a download href="{{path '../../icons/png/ontario-icon-transport-bicycle.png'}}">PNG</a> , <a target="_blank" href="{{path '../../icons/svg/ontario-icon-transport-bicycle.svg'}}" download="ontario-icon-transport-bicycle.svg">SVG</a>
|{{{render '@icons-secondary--ontario-icon-transport-bus' }}} | ontario-icon-transport-bus| <a download href="{{path '../../icons/png/ontario-icon-transport-bus.png'}}">PNG</a> , <a target="_blank" href="{{path '../../icons/svg/ontario-icon-transport-bus.svg'}}" download="ontario-icon-transport-bus.svg">SVG</a>
|{{{render '@icons-secondary--ontario-icon-transport-car' }}} | ontario-icon-transport-car| <a download href="{{path '../../icons/png/ontario-icon-transport-car.png'}}">PNG</a> , <a target="_blank" href="{{path '../../icons/svg/ontario-icon-transport-car.svg'}}" download="ontario-icon-transport-car.svg">SVG</a>
|{{{render '@icons-secondary--ontario-icon-transport-walk' }}} | ontario-icon-transport-walk| <a download href="{{path '../../icons/png/ontario-icon-transport-walk.png'}}">PNG</a> , <a target="_blank" href="{{path '../../icons/svg/ontario-icon-transport-walk.svg'}}" download="ontario-icon-transport-walk.svg">SVG</a>
|{{{render '@icons-secondary--ontario-icon-wheelchair' }}} | ontario-icon-wheelchair| <a download href="{{path '../../icons/png/ontario-icon-wheelchair.png'}}">PNG</a> , <a target="_blank" href="{{path '../../icons/svg/ontario-icon-wheelchair.svg'}}" download="ontario-icon-wheelchair.svg">SVG</a>

</div>

<br>

#### <a name="7"></a>Feedback

<div class="fractal-table-scroll">

|Icon |Icon name  |Download |
| ------| -----|  -----|
|{{{render '@icons-secondary--ontario-icon-sentiment-1' }}} | ontario-icon-sentiment-1| <a download href="{{path '../../icons/png/ontario-icon-sentiment-1.png'}}">PNG</a> , <a target="_blank" href="{{path '../../icons/svg/ontario-icon-sentiment-1.svg'}}" download="ontario-icon-sentiment-1.svg">SVG</a>
|{{{render '@icons-secondary--ontario-icon-sentiment-2' }}} | ontario-icon-sentiment-2| <a download href="{{path '../../icons/png/ontario-icon-sentiment-2.png'}}">PNG</a> , <a target="_blank" href="{{path '../../icons/svg/ontario-icon-sentiment-2.svg'}}" download="ontario-icon-sentiment-2.svg">SVG</a>
|{{{render '@icons-secondary--ontario-icon-sentiment-3' }}} | ontario-icon-sentiment-3| <a download href="{{path '../../icons/png/ontario-icon-sentiment-3.png'}}">PNG</a> , <a target="_blank" href="{{path '../../icons/svg/ontario-icon-sentiment-3.svg'}}" download="ontario-icon-sentiment-3.svg">SVG</a>
|{{{render '@icons-secondary--ontario-icon-sentiment-4' }}} | ontario-icon-sentiment-4| <a download href="{{path '../../icons/png/ontario-icon-sentiment-4.png'}}">PNG</a> , <a target="_blank" href="{{path '../../icons/svg/ontario-icon-sentiment-4.svg'}}" download="ontario-icon-sentiment-4.svg">SVG</a>
|{{{render '@icons-secondary--ontario-icon-sentiment-5' }}} | ontario-icon-sentiment-5| <a download href="{{path '../../icons/png/ontario-icon-sentiment-5.png'}}">PNG</a> , <a target="_blank" href="{{path '../../icons/svg/ontario-icon-sentiment-5.svg'}}" download="ontario-icon-sentiment-5.svg">SVG</a>
|{{{render '@icons-secondary--ontario-icon-vote-dislike' }}} | ontario-icon-vote-dislike| <a download href="{{path '../../icons/png/ontario-icon-vote-dislike.png'}}">PNG</a> , <a target="_blank" href="{{path '../../icons/svg/ontario-icon-vote-dislike.svg'}}" download="ontario-icon-vote-dislike.svg">SVG</a>
|{{{render '@icons-secondary--ontario-icon-vote-like' }}} | ontario-icon-vote-like| <a download href="{{path '../../icons/png/ontario-icon-vote-like.png'}}">PNG</a> , <a target="_blank" href="{{path '../../icons/svg/ontario-icon-vote-like.svg'}}" download="ontario-icon-vote-like.svg">SVG</a>

</div>

<hr>

## How to use secondary icons

Copy and paste the <abbr title="Scalable Vector Graphics">SVG</abbr> code for the main icon file. Include this in your code. Note that you will need to include the polyfill in order to make sure that icons render properly on <abbr title="Internet Explorer 11">IE11.</abbr>

Load the secondary icons svg store from a self-hosted file or our <abbr title="Content delivery network">CDN</abbr>. Note that you will need to include the polyfill in order to make sure that icons render properly on <abbr title="Internet Explorer 11">IE11.</abbr>

1. Load the icons, there are two options:

    * Download the secondary icons file and host the file on your server or website<br><a download href="{{path '../../icons/ontario-icons-secondary.svg'}}">Download secondary icons SVG store here</a>
    
    * Use our hosted file <br> https://designsystem.ontario.ca/icons/ontario-icons-secondary.svg

2. Add the <a download href="{{path '../../scripts/svgxuse.js'}}">polyfill</a> that fixes SVGs on <abbr title="internet explorer">IE</abbr> and other older browsers. 
<br>{{{render '@inline-code--icons-secondary-setup' }}}

3. Use the html SVG in your code
    * If self-hosting the ontario-icons-secondary.svg, use the code below and adjust the xlink:href to the correct path:
    <br>{{{render '@inline-code--icons-secondary' }}}

    * To use our hosted secondary icons SVG file set the xlink:href, for example to: ``` https://designsystem.ontario.ca/icons/ontario-icons-secondary.svg#ontario-icon-account ```

4. Add CSS class ontario-icon from the SCSS or Compiled CSS tab to your project's CSS file.

<hr>

## Technical specifications (for both primary and secondary icons)

<div class="fractal-table-scroll">

|File type |SVG |
| -----------| -----|
|Size|Minimum `16px`<br>Maximum H1 (`40px` on desktop, `32px` on mobile)|
|Hit size|If the icon is clickable, the hit area should be at least `48px` by `48px` (see [radio buttons]({{path '../radio-buttons.html'}}) for an example of where the hit size is larger than the element)<br><br>If the icon is a standalone component, it should have a hit area of `48px` by `48px`. If the icon is clickable and in line with text, it should be the same size as the font.|
|Colour|Black: `#1A1A1A`<br>White: `#FFFFFF`<br>Grey: `#666666`<br>Blue (if a link):<br> <ul><li>Normal: `#0066CC`</li><li>Hover: `#004E99`</li><li>Visited: `#551A8B`</li></ul><br>Exceptions: some icons come with colours hard-coded into them. Do not override hard-coded icon colours. Examples include:<br><ul><li>alert icons (red, green and yellow)</li><li>Visa, Mastercard, and Interac icons</li></ul>

</div>

<hr>

## Help improve this page
If you have other suggestions or advice or any questions on icons, the [design system team]({{path '../../docs/give-feedback.html'}}) would love to hear from you.
