**[Principe directeur]({{path '../../docs/documentation/design-principles.html'}})&nbsp;:** N’insérer que des éléments qui ont un rôle à jouer

## Directive générale sur les icônes

Les icônes sont une représentation **visuelle d’un objet, d’une action ou d’une idée simple et unique**. Si vous avez besoin de communiquer des concepts plus complexes, envisagez une illustration ou une infographie.

### Bibliothèque d’icônes du système de conception de l’Ontario 

La bibliothèque d’icônes du système de conception de l’Ontario est composée de deux ensembles&nbsp;:
- [icônes primaires]({{path './icons-primary.html'}})&nbsp;: cet ensemble représente les concepts les plus couramment utilisés dans le cadre de nos services (p. ex. téléphone, menu, recherche)
- [icônes secondaires]({{path './icons-secondary.html'}})&nbsp;: cet ensemble représente des concepts qui sont plus ou moins souvent utilisés (comme joindre, imprimer, épingler une carte)

#### Si vous avez besoin d’une icône différente

Si notre bibliothèque d’icônes ne contient pas le concept que vous devez représenter, vous pouvez choisir une icône dans le système Material Design de Google&nbsp;:
- [bibliothèque d’icônes](https://material.io/resources/icons/?style=baseline) (utilisez les versions remplies)
- [bibliothèque d’iconographie pilotée par la communauté](https://materialdesignicons.com/)

Toutes les fois que vous avez besoin d’une icône qui ne se trouve pas dans notre bibliothèque d’icônes, veuillez en informer [l’équipe du système de conception]({{path '../../docs/give-feedback.html'}}). Si nous constatons que les mêmes sont couramment utilisées, nous envisagerons de les ajouter à la bibliothèque.

<hr>

## Pourquoi choisissons-nous ces icônes?
Le système de conception de l’Ontario suit les principes de conception d’icônes du [système Material Design](https://material.io/design/iconography/system-icons.html) et utilise les icônes de la bibliothèque de  [Material Design](https://material.io/tools/icons/?style=baseline).

Nous avons choisi les icônes de notre bibliothèque en nous fondant sur les [meilleures pratiques](https://www.nngroup.com/articles/icon-usability/) qui ont fait leurs preuves, à savoir que toutes les icônes que nous utilisons doivent être&nbsp;:

- une représentation visuelle **d'un seul objet, d'une seule action ou d'une seule idée**
- faciles à **reconnaître et à comprendre**
- susceptibles d'être **interprétées de la même façon** par les utilisateurs
- utilisées pour représenter la «&nbsp;**reconnaissance universelle**&nbsp;» par opposition à la «&nbsp;représentation universelle&nbsp;»
  - par exemple, un fauteuil roulant est souvent utilisé pour l'accessibilité, même s'il ne représente pas tous les types de handicaps
- **pratiques**
  - les icônes doivent guider l'utilisateur dans l'accomplissement de sa tâche.  -- **n'utilisez pas les icônes dans un but purement visuel**.

<hr>

## Ensemble d’icônes secondaires
Ces icônes représentent des concepts qui sont souvent utilisés, mais pas aussi souvent que ceux de l’ensemble primaire (comme joindre, imprimer, épingler une carte).

<a href="#how-to-use-secondary-icons">Passer à Comment utiliser les icônes secondaires.</a>

Toutes les icônes suivent le modèle de dénomination «&nbsp;ontario-icon-purpose&nbsp;». Vous pouvez rechercher des icônes particulières en utilisant la commande Rechercher de votre navigateur  (`ctrl+f` sur un PC, `⌘+f` sur on Mac)

<a download href="{{path '../../icons/png/ontario-icons-archive-pngs.zip'}}">Télécharger toutes les icônes en format PNG</a>

### Catégories d’icônes secondaires

Nous avons classé les icônes secondaires dans ces catégories&nbsp;:
- [Comptes et applications Web](#1) 
- [Interactions](#2)
- [Multimédia](#3)
- [Communications et médias sociaux](#4)
- [Paiement](#5)
- [Cartes et transports](#6)
- [Commentaires](#7)

#### <a name="1"></a>Comptes et applications Web

<div class="fractal-table-scroll">

|Icône |Nom de l’icône |Usage ou alias |Téléchargement |
| ------| -----| ----------------------| -----|
|{{{render '@icons-secondary--ontario-icon-account' }}} | ontario-icon-account| |<a download href="{{path '../../icons/png/ontario-icon-account.png'}}">PNG</a> , <a target="_blank" href="{{path '../../icons/svg/ontario-icon-account.svg'}}" download="ontario-icon-account.svg">SVG</a>
|{{{render '@icons-secondary--ontario-icon-bookmark-off' }}} | ontario-icon-bookmark-off| Favoris, enregistrer|<a download href="{{path '../../icons/png/ontario-icon-bookmark-off.png'}}">PNG</a> , <a target="_blank" href="{{path '../../icons/svg/ontario-icon-bookmark-off.svg'}}" download="ontario-icon-bookmark-off.svg">SVG</a>
|{{{render '@icons-secondary--ontario-icon-bookmark-on' }}} | ontario-icon-bookmark-on| Favoris, enregistrer|<a download href="{{path '../../icons/png/ontario-icon-bookmark-on.png'}}">PNG</a> , <a target="_blank" href="{{path '../../icons/svg/ontario-icon-bookmark-on.svg'}}" download="ontario-icon-bookmark-on.svg">SVG</a>
|{{{render '@icons-secondary--ontario-icon-cloud' }}} | ontario-icon-cloud| |<a download href="{{path '../../icons/png/ontario-icon-cloud.png'}}">PNG</a> , <a target="_blank" href="{{path '../../icons/svg/ontario-icon-cloud.svg'}}" download="ontario-icon-cloud.svg">SVG</a>
|{{{render '@icons-secondary--ontario-icon-more-vertical' }}} | ontario-icon-more-vertical| |<a download href="{{path '../../icons/png/ontario-icon-more-vertical.png'}}">PNG</a> , <a target="_blank" href="{{path '../../icons/svg/ontario-icon-more-vertical.svg'}}" download="ontario-icon-more-vertical.svg">SVG</a>
|{{{render '@icons-secondary--ontario-icon-notification' }}} | ontario-icon-notification| Alerte|<a download href="{{path '../../icons/png/ontario-icon-notification.png'}}">PNG</a> , <a target="_blank" href="{{path '../../icons/svg/ontario-icon-notification.svg'}}" download="ontario-icon-notification.svg">SVG</a>
|{{{render '@icons-secondary--ontario-icon-password-hide' }}} | ontario-icon-password-hide| |<a download href="{{path '../../icons/png/ontario-icon-password-hide.png'}}">PNG</a> , <a target="_blank" href="{{path '../../icons/svg/ontario-icon-password-hide.svg'}}" download="ontario-icon-password-hide.svg">SVG</a>
|{{{render '@icons-secondary--ontario-icon-password-show' }}} | ontario-icon-password-show| |<a download href="{{path '../../icons/png/ontario-icon-password-show.png'}}">PNG</a> , <a target="_blank" href="{{path '../../icons/svg/ontario-icon-password-show.svg'}}" download="ontario-icon-password-show.svg">SVG</a>
|{{{render '@icons-secondary--ontario-icon-settings' }}} | ontario-icon-settings| |<a download href="{{path '../../icons/png/ontario-icon-settings.png'}}">PNG</a> , <a target="_blank" href="{{path '../../icons/svg/ontario-icon-settings.svg'}}" download="ontario-icon-settings.svg">SVG</a>
|{{{render '@icons-secondary--ontario-icon-tag' }}} | ontario-icon-tag| |<a download href="{{path '../../icons/png/ontario-icon-tag.png'}}">PNG</a> , <a target="_blank" href="{{path '../../icons/svg/ontario-icon-tag.svg'}}" download="ontario-icon-tag.svg">SVG</a>

</div>

<br>

#### <a name="2"></a>Interactions

<div class="fractal-table-scroll">

|Icône |Nom de l’icône |Usage ou alias |Téléchargement |
| ------| -----| ----------------------| -----|
|{{{render '@icons-secondary--ontario-icon-attach' }}} | ontario-icon-attach| Pièce jointe, fichier|<a download href="{{path '../../icons/png/ontario-icon-attach.png'}}">PNG</a> , <a target="_blank" href="{{path '../../icons/svg/ontario-icon-attach.svg'}}" download="ontario-icon-attach.svg">SVG</a>
|{{{render '@icons-secondary--ontario-icon-calendar' }}} | ontario-icon-calendar| Date, sélecteur de dates|<a download href="{{path '../../icons/png/ontario-icon-calendar.png'}}">PNG</a> , <a target="_blank" href="{{path '../../icons/svg/ontario-icon-calendar.svg'}}" download="ontario-icon-calendar.svg">SVG</a>
|{{{render '@icons-secondary--ontario-icon-clock' }}} | ontario-icon-clock| Heure, échéancier|<a download href="{{path '../../icons/png/ontario-icon-clock.png'}}">PNG</a> , <a target="_blank" href="{{path '../../icons/svg/ontario-icon-clock.svg'}}" download="ontario-icon-clock.svg">SVG</a>
|{{{render '@icons-secondary--ontario-icon-delete' }}} | ontario-icon-delete| Effacer, supprimer|<a download href="{{path '../../icons/png/ontario-icon-delete.png'}}">PNG</a> , <a target="_blank" href="{{path '../../icons/svg/ontario-icon-delete.svg'}}" download="ontario-icon-delete.svg">SVG</a>
|{{{render '@icons-secondary--ontario-icon-document' }}} | ontario-icon-document| Joindre, type de fichier, fichier|<a download href="{{path '../../icons/png/ontario-icon-document.png'}}">PNG</a> , <a target="_blank" href="{{path '../../icons/svg/ontario-icon-document.svg'}}" download="ontario-icon-document.svg">SVG</a>
|{{{render '@icons-secondary--ontario-icon-download' }}} | ontario-icon-download| |<a download href="{{path '../../icons/png/ontario-icon-download.png'}}">PNG</a> , <a target="_blank" href="{{path '../../icons/svg/ontario-icon-download.svg'}}" download="ontario-icon-download.svg">SVG</a>
|{{{render '@icons-secondary--ontario-icon-edit' }}} | ontario-icon-edit| |<a download href="{{path '../../icons/png/ontario-icon-edit.png'}}">PNG</a> , <a target="_blank" href="{{path '../../icons/svg/ontario-icon-edit.svg'}}" download="ontario-icon-edit.svg">SVG</a>
|{{{render '@icons-secondary--ontario-icon-export' }}} | ontario-icon-export| |<a download href="{{path '../../icons/png/ontario-icon-export.png'}}">PNG</a> , <a target="_blank" href="{{path '../../icons/svg/ontario-icon-export.svg'}}" download="ontario-icon-export.svg">SVG</a>
|{{{render '@icons-secondary--ontario-icon-favourite-off' }}} | ontario-icon-favourite-off| J’aime, enregistrer, cœur |<a download href="{{path '../../icons/png/ontario-icon-favourite-off.png'}}">PNG</a> , <a target="_blank" href="{{path '../../icons/svg/ontario-icon-favourite-off.svg'}}" download="ontario-icon-favourite-off.svg">SVG</a>
|{{{render '@icons-secondary--ontario-icon-favourite-on' }}} | ontario-icon-favourite-on| J’aime, enregistrer, cœur |<a download href="{{path '../../icons/png/ontario-icon-favourite-on.png'}}">PNG</a> , <a target="_blank" href="{{path '../../icons/svg/ontario-icon-favourite-on.svg'}}" download="ontario-icon-favourite-on.svg">SVG</a>
|{{{render '@icons-secondary--ontario-icon-filter' }}} | ontario-icon-filter| Filtre|<a download href="{{path '../../icons/png/ontario-icon-filter.png'}}">PNG</a> , <a target="_blank" href="{{path '../../icons/svg/ontario-icon-filter.svg'}}" download="ontario-icon-filter.svg">SVG</a>
|{{{render '@icons-secondary--ontario-icon-grid' }}} | ontario-icon-grid| Changer d’affichage|<a download href="{{path '../../icons/png/ontario-icon-grid.png'}}">PNG</a> , <a target="_blank" href="{{path '../../icons/svg/ontario-icon-grid.svg'}}" download="ontario-icon-grid.svg">SVG</a>
|{{{render '@icons-secondary--ontario-icon-list' }}} | ontario-icon-list| Changer d’affichage|<a download href="{{path '../../icons/png/ontario-icon-list.png'}}">PNG</a> , <a target="_blank" href="{{path '../../icons/svg/ontario-icon-list.svg'}}" download="ontario-icon-list.svg">SVG</a>
|{{{render '@icons-secondary--ontario-icon-location-off' }}} | ontario-icon-location-off| Désactiver l’emplacement, gps|<a download href="{{path '../../icons/png/ontario-icon-location-off.png'}}">PNG</a> , <a target="_blank" href="{{path '../../icons/svg/ontario-icon-location-off.svg'}}" download="ontario-icon-location-off.svg">SVG</a>
|{{{render '@icons-secondary--ontario-icon-location-on' }}} | ontario-icon-location-on| Rechercher un emplacement, gps|<a download href="{{path '../../icons/png/ontario-icon-location-on.png'}}">PNG</a> , <a target="_blank" href="{{path '../../icons/svg/ontario-icon-location-on.svg'}}" download="ontario-icon-location-on.svg">SVG</a>
|{{{render '@icons-secondary--ontario-icon-lock-on' }}} | ontario-icon-lock-on| Sécurisé, mot de passe|<a download href="{{path '../../icons/png/ontario-icon-lock-on.png'}}">PNG</a> , <a target="_blank" href="{{path '../../icons/svg/ontario-icon-lock-on.svg'}}" download="ontario-icon-lock-on.svg">SVG</a>
|{{{render '@icons-secondary--ontario-icon-lock-off' }}} | ontario-icon-lock-off| Sécurisé, mot de passe|<a download href="{{path '../../icons/png/ontario-icon-lock-off.png'}}">PNG</a> , <a target="_blank" href="{{path '../../icons/svg/ontario-icon-lock-off.svg'}}" download="ontario-icon-lock-off.svg">SVG</a>
|{{{render '@icons-secondary--ontario-icon-next' }}} | ontario-icon-next| |<a download href="{{path '../../icons/png/ontario-icon-next.png'}}">PNG</a> , <a target="_blank" href="{{path '../../icons/svg/ontario-icon-next.svg'}}" download="ontario-icon-next.svg">SVG</a>
|{{{render '@icons-secondary--ontario-icon-pin-location-off' }}} | ontario-icon-pin-location-off| Rechercher un emplacement|<a download href="{{path '../../icons/png/ontario-icon-pin-location-off.png'}}">PNG</a> , <a target="_blank" href="{{path '../../icons/svg/ontario-icon-pin-location-off.svg'}}" download="ontario-icon-pin-location-off.svg">SVG</a>
|{{{render '@icons-secondary--ontario-icon-pin-location-on' }}} | ontario-icon-pin-location-on| Rechercher un emplacement|<a download href="{{path '../../icons/png/ontario-icon-pin-location-on.png'}}">PNG</a> , <a target="_blank" href="{{path '../../icons/svg/ontario-icon-pin-location-on.svg'}}" download="ontario-icon-pin-location-on.svg">SVG</a>
|{{{render '@icons-secondary--ontario-icon-previous' }}} | ontario-icon-previous| |<a download href="{{path '../../icons/png/ontario-icon-previous.png'}}">PNG</a> , <a target="_blank" href="{{path '../../icons/svg/ontario-icon-previous.svg'}}" download="ontario-icon-previous.svg">SVG</a>
|{{{render '@icons-secondary--ontario-icon-print' }}} | ontario-icon-print| Imprimer|<a download href="{{path '../../icons/png/ontario-icon-print.png'}}">PNG</a> , <a target="_blank" href="{{path '../../icons/svg/ontario-icon-print.svg'}}" download="ontario-icon-print.svg">SVG</a>
|{{{render '@icons-secondary--ontario-icon-save' }}} | ontario-icon-save| Enregistrer|<a download href="{{path '../../icons/png/ontario-icon-save.png'}}">PNG</a> , <a target="_blank" href="{{path '../../icons/svg/ontario-icon-save.svg'}}" download="ontario-icon-save.svg">SVG</a>
|{{{render '@icons-secondary--ontario-icon-sort' }}} | ontario-icon-sort| Trier|<a download href="{{path '../../icons/png/ontario-icon-sort.png'}}">PNG</a> , <a target="_blank" href="{{path '../../icons/svg/ontario-icon-sort.svg'}}" download="ontario-icon-sort.svg">SVG</a>
|{{{render '@icons-secondary--ontario-icon-timer' }}} | ontario-icon-timer| Chronomètre|<a download href="{{path '../../icons/png/ontario-icon-timer.png'}}">PNG</a> , <a target="_blank" href="{{path '../../icons/svg/ontario-icon-timer.svg'}}" download="ontario-icon-timer.svg">SVG</a>
|{{{render '@icons-secondary--ontario-icon-upload' }}} | ontario-icon-upload| |<a download href="{{path '../../icons/png/ontario-icon-upload.png'}}">PNG</a> , <a target="_blank" href="{{path '../../icons/svg/ontario-icon-upload.svg'}}" download="ontario-icon-upload.svg">SVG</a>
|{{{render '@icons-secondary--ontario-icon-vpn-key' }}} | ontario-icon-vpn-key| |<a download href="{{path '../../icons/png/ontario-icon-vpn-key.png'}}">PNG</a> , <a target="_blank" href="{{path '../../icons/svg/ontario-icon-vpn-key.svg'}}" download="ontario-icon-vpn-key.svg">SVG</a>

</div>

<br>

#### <a name="3"></a>Multimédia

<div class="fractal-table-scroll">

|Icône |Nom de l’icône |Usage ou alias |Téléchargement |
| ------| -----| ----------------------| -----|
|{{{render '@icons-secondary--ontario-icon-camera' }}} | ontario-icon-camera| |<a download href="{{path '../../icons/png/ontario-icon-camera.png'}}">PNG</a> , <a target="_blank" href="{{path '../../icons/svg/ontario-icon-camera.svg'}}" download="ontario-icon-camera.svg">SVG</a>
|{{{render '@icons-secondary--ontario-icon-media-fast-forward' }}} | ontario-icon-media-fast-forward| Accélérer|<a download href="{{path '../../icons/png/ontario-icon-media-fast-forward.png'}}">PNG</a> , <a target="_blank" href="{{path '../../icons/svg/ontario-icon-media-fast-forward.svg'}}" download="ontario-icon-media-fast-forward.svg">SVG</a>
|{{{render '@icons-secondary--ontario-icon-media-fast-rewind' }}} | ontario-icon-media-fast-rewind| Retour|<a download href="{{path '../../icons/png/ontario-icon-media-fast-rewind.png'}}">PNG</a> , <a target="_blank" href="{{path '../../icons/svg/ontario-icon-media-fast-rewind.svg'}}" download="ontario-icon-media-fast-rewind.svg">SVG</a>
|{{{render '@icons-secondary--ontario-icon-media-pause' }}} | ontario-icon-media-pause| |<a download href="{{path '../../icons/png/ontario-icon-media-pause.png'}}">PNG</a> , <a target="_blank" href="{{path '../../icons/svg/ontario-icon-media-pause.svg'}}" download="ontario-icon-media-pause.svg">SVG</a>
|{{{render '@icons-secondary--ontario-icon-media-play' }}} | ontario-icon-media-play| |<a download href="{{path '../../icons/png/ontario-icon-media-play.png'}}">PNG</a> , <a target="_blank" href="{{path '../../icons/svg/ontario-icon-media-play.svg'}}" download="ontario-icon-media-play.svg">SVG</a>
|{{{render '@icons-secondary--ontario-icon-media-stop' }}} | ontario-icon-media-stop| |<a download href="{{path '../../icons/png/ontario-icon-media-stop.png'}}">PNG</a> , <a target="_blank" href="{{path '../../icons/svg/ontario-icon-media-stop.svg'}}" download="ontario-icon-media-stop.svg">SVG</a>
|{{{render '@icons-secondary--ontario-icon-microphone-off' }}} | ontario-icon-microphone-off| Enregistrer|<a download href="{{path '../../icons/png/ontario-icon-microphone-off.png'}}">PNG</a> , <a target="_blank" href="{{path '../../icons/svg/ontario-icon-microphone-off.svg'}}" download="ontario-icon-microphone-off.svg">SVG</a>
|{{{render '@icons-secondary--ontario-icon-microphone-on' }}} | ontario-icon-microphone-on| Enregistrer|<a download href="{{path '../../icons/png/ontario-icon-microphone-on.png'}}">PNG</a> , <a target="_blank" href="{{path '../../icons/svg/ontario-icon-microphone-on.svg'}}" download="ontario-icon-microphone-on.svg">SVG</a>
|{{{render '@icons-secondary--ontario-icon-photo' }}} | ontario-icon-photo| |<a download href="{{path '../../icons/png/ontario-icon-photo.png'}}">PNG</a> , <a target="_blank" href="{{path '../../icons/svg/ontario-icon-photo.svg'}}" download="ontario-icon-photo.svg">SVG</a>
|{{{render '@icons-secondary--ontario-icon-replay' }}} | ontario-icon-replay| |<a download href="{{path '../../icons/png/ontario-icon-replay.png'}}">PNG</a> , <a target="_blank" href="{{path '../../icons/svg/ontario-icon-replay.svg'}}" download="ontario-icon-replay.svg">SVG</a>
|{{{render '@icons-secondary--ontario-icon-video' }}} | ontario-icon-video| |<a download href="{{path '../../icons/png/ontario-icon-video.png'}}">PNG</a> , <a target="_blank" href="{{path '../../icons/svg/ontario-icon-video.svg'}}" download="ontario-icon-video.svg">SVG</a>
|{{{render '@icons-secondary--ontario-icon-wifi' }}} | ontario-icon-wifi| |<a download href="{{path '../../icons/png/ontario-icon-wifi.png'}}">PNG</a> , <a target="_blank" href="{{path '../../icons/svg/ontario-icon-wifi.svg'}}" download="ontario-icon-wifi.svg">SVG</a>

</div>

<br>

#### <a name="4"></a>Communications et médias sociaux

<div class="fractal-table-scroll">

|Icône |Nom de l’icône |Usage ou alias |Téléchargement |
| ------| -----|------  |-----|
|{{{render '@icons-secondary--ontario-icon-facebook'}}} | ontario-icon-facebook| |<a download href="{{path '../../icons/png/ontario-icon-facebook.png'}}">PNG</a> , <a target="_blank" href="{{path '../../icons/svg/ontario-icon-facebook.svg'}}" download="ontario-icon-facebook.svg">SVG</a>
|{{{render '@icons-secondary--ontario-icon-facebook-alt'}}} | ontario-icon-facebook-alt| |<a download href="{{path '../../icons/png/ontario-icon-facebook-alt.png'}}">PNG</a> , <a target="_blank" href="{{path '../../icons/svg/ontario-icon-facebook-alt.svg'}}" download="ontario-icon-facebook-alt.svg">SVG</a>
|{{{render '@icons-secondary--ontario-icon-flickr'}}} | ontario-icon-flickr| |<a download href="{{path '../../icons/png/ontario-icon-flickr.png'}}">PNG</a> , <a target="_blank" href="{{path '../../icons/svg/ontario-icon-flickr.svg'}}" download="ontario-icon-flickr.svg">SVG</a>
|{{{render '@icons-secondary--ontario-icon-instagram'}}} | ontario-icon-instagram| |<a download href="{{path '../../icons/png/ontario-icon-instagram.png'}}">PNG</a> , <a target="_blank" href="{{path '../../icons/svg/ontario-icon-instagram.svg'}}" download="ontario-icon-instagram.svg">SVG</a>
|{{{render '@icons-secondary--ontario-icon-linkedin'}}} | ontario-icon-linkedin| |<a download href="{{path '../../icons/png/ontario-icon-linkedin.png'}}">PNG</a> , <a target="_blank" href="{{path '../../icons/svg/ontario-icon-linkedin.svg'}}" download="ontario-icon-linkedin.svg">SVG</a>
|{{{render '@icons-secondary--ontario-icon-linkedin-alt'}}} | ontario-icon-linkedin-alt| |<a download href="{{path '../../icons/png/ontario-icon-linkedin-alt.png'}}">PNG</a> , <a target="_blank" href="{{path '../../icons/svg/ontario-icon-linkedin-alt.svg'}}" download="ontario-icon-linkedin-alt.svg">SVG</a>
|{{{render '@icons-secondary--ontario-icon-live-chat'}}} | ontario-icon-live-chat| |<a download href="{{path '../../icons/png/ontario-icon-live-chat.png'}}">PNG</a> , <a target="_blank" href="{{path '../../icons/svg/ontario-icon-live-chat.svg'}}" download="ontario-icon-live-chat.svg">SVG</a>
|{{{render '@icons-secondary--ontario-icon-rss-feed'}}} | ontario-icon-rss-feed| |<a download href="{{path '../../icons/png/ontario-icon-rss-feed.png'}}">PNG</a> , <a target="_blank" href="{{path '../../icons/svg/ontario-icon-rss-feed.svg'}}" download="ontario-icon-rss-feed.svg">SVG</a>
|{{{render '@icons-secondary--ontario-icon-share'}}} | ontario-icon-share| |<a download href="{{path '../../icons/png/ontario-icon-share.png'}}">PNG</a> , <a target="_blank" href="{{path '../../icons/svg/ontario-icon-share.svg'}}" download="ontario-icon-share.svg">SVG</a>
|{{{render '@icons-secondary--ontario-icon-text-message'}}} | ontario-icon-text-message| sms, message texte|<a download href="{{path '../../icons/png/ontario-icon-text-message.png'}}">PNG</a> , <a target="_blank" href="{{path '../../icons/svg/ontario-icon-text-message.svg'}}" download="ontario-icon-text-message.svg">SVG</a>
|{{{render '@icons-secondary--ontario-icon-twitter'}}} | ontario-icon-twitter| |<a download href="{{path '../../icons/png/ontario-icon-twitter.png'}}">PNG</a> , <a target="_blank" href="{{path '../../icons/svg/ontario-icon-twitter.svg'}}" download="ontario-icon-twitter.svg">SVG</a>
|{{{render '@icons-secondary--ontario-icon-twitter-alt'}}} | ontario-icon-twitter-alt| |<a download href="{{path '../../icons/png/ontario-icon-twitter-alt.png'}}">PNG</a> , <a target="_blank" href="{{path '../../icons/svg/ontario-icon-twitter-alt.svg'}}" download="ontario-icon-twitter-alt.svg">SVG</a>
|{{{render '@icons-secondary--ontario-icon-youtube'}}} | ontario-icon-youtube| |<a download href="{{path '../../icons/png/ontario-icon-youtube.png'}}">PNG</a> , <a target="_blank" href="{{path '../../icons/svg/ontario-icon-youtube.svg'}}" download="ontario-icon-youtube.svg">SVG</a>

</div>

<br>

#### <a name="5"></a>Paiement

<div class="fractal-table-scroll">

|Icône |Nom de l’icône |Téléchargement |
| ------| -----|-----|
|{{{render '@icons-secondary--ontario-icon-interac-en' }}} | ontario-icon-interac-en| <a download href="{{path '../../icons/png/ontario-icon-interac-en.png'}}">PNG</a> , <a target="_blank" href="{{path '../../icons/svg/ontario-icon-interac-en.svg'}}" download="ontario-icon-interac-en.svg">SVG</a>
|{{{render '@icons-secondary--ontario-icon-interac-fr' }}} | ontario-icon-interac-fr| <a download href="{{path '../../icons/png/ontario-icon-interac-fr.png'}}">PNG</a> , <a target="_blank" href="{{path '../../icons/svg/ontario-icon-interac-fr.svg'}}" download="ontario-icon-interac-fr.svg">SVG</a>
|{{{render '@icons-secondary--ontario-icon-interac-en-alt' }}} | ontario-icon-interac-en-alt| <a download href="{{path '../../icons/png/ontario-icon-interac-en-alt.png'}}">PNG</a> , <a target="_blank" href="{{path '../../icons/svg/ontario-icon-interac-en-alt.svg'}}" download="ontario-icon-interac-en-alt.svg">SVG</a>
|{{{render '@icons-secondary--ontario-icon-interac-fr-alt' }}} | ontario-icon-interac-fr-alt| <a download href="{{path '../../icons/png/ontario-icon-interac-fr-alt.png'}}">PNG</a> , <a target="_blank" href="{{path '../../icons/svg/ontario-icon-interac-fr-alt.svg'}}" download="ontario-icon-interac-fr-alt.svg">SVG</a>
|{{{render '@icons-secondary--ontario-icon-mastercard' }}} | ontario-icon-mastercard| <a download href="{{path '../../icons/png/ontario-icon-mastercard.png'}}">PNG</a> , <a target="_blank" href="{{path '../../icons/svg/ontario-icon-mastercard.svg'}}" download="ontario-icon-mastercard.svg">SVG</a>
|{{{render '@icons-secondary--ontario-icon-mastercard-alt' }}} | ontario-icon-mastercard-alt| <a download href="{{path '../../icons/png/ontario-icon-mastercard-alt.png'}}">PNG</a> , <a target="_blank" href="{{path '../../icons/svg/ontario-icon-mastercard-alt.svg'}}" download="ontario-icon-mastercard-alt.svg">SVG</a>
|{{{render '@icons-secondary--ontario-icon-visa' }}} | ontario-icon-visa| <a download href="{{path '../../icons/png/ontario-icon-visa.png'}}">PNG</a> , <a target="_blank" href="{{path '../../icons/svg/ontario-icon-visa.svg'}}" download="ontario-icon-visa.svg">SVG</a>

</div>

<br>

#### <a name="6"></a>Cartes et transports

<div class="fractal-table-scroll">

|Icône |Nom de l’icône |Téléchargement |
| ------| -----|---------|
|{{{render '@icons-secondary--ontario-icon-map' }}} | ontario-icon-map| <a download href="{{path '../../icons/png/ontario-icon-map.png'}}">PNG</a> , <a target="_blank" href="{{path '../../icons/svg/ontario-icon-map.svg'}}" download="ontario-icon-map.svg">SVG</a>
|{{{render '@icons-secondary--ontario-icon-transport-bicycle' }}} | ontario-icon-transport-bicycle| <a download href="{{path '../../icons/png/ontario-icon-transport-bicycle.png'}}">PNG</a> , <a target="_blank" href="{{path '../../icons/svg/ontario-icon-transport-bicycle.svg'}}" download="ontario-icon-transport-bicycle.svg">SVG</a>
|{{{render '@icons-secondary--ontario-icon-transport-bus' }}} | ontario-icon-transport-bus| <a download href="{{path '../../icons/png/ontario-icon-transport-bus.png'}}">PNG</a> , <a target="_blank" href="{{path '../../icons/svg/ontario-icon-transport-bus.svg'}}" download="ontario-icon-transport-bus.svg">SVG</a>
|{{{render '@icons-secondary--ontario-icon-transport-car' }}} | ontario-icon-transport-car| <a download href="{{path '../../icons/png/ontario-icon-transport-car.png'}}">PNG</a> , <a target="_blank" href="{{path '../../icons/svg/ontario-icon-transport-car.svg'}}" download="ontario-icon-transport-car.svg">SVG</a>
|{{{render '@icons-secondary--ontario-icon-transport-walk' }}} | ontario-icon-transport-walk| <a download href="{{path '../../icons/png/ontario-icon-transport-walk.png'}}">PNG</a> , <a target="_blank" href="{{path '../../icons/svg/ontario-icon-transport-walk.svg'}}" download="ontario-icon-transport-walk.svg">SVG</a>
|{{{render '@icons-secondary--ontario-icon-wheelchair' }}} | ontario-icon-wheelchair| <a download href="{{path '../../icons/png/ontario-icon-wheelchair.png'}}">PNG</a> , <a target="_blank" href="{{path '../../icons/svg/ontario-icon-wheelchair.svg'}}" download="ontario-icon-wheelchair.svg">SVG</a>

</div>

<br>

#### <a name="7"></a>Commentaires

<div class="fractal-table-scroll">

|Icône |Nom de l’icône |Téléchargement |
| ------| -----|  -----|
|{{{render '@icons-secondary--ontario-icon-sentiment-1' }}} | ontario-icon-sentiment-1| <a download href="{{path '../../icons/png/ontario-icon-sentiment-1.png'}}">PNG</a> , <a target="_blank" href="{{path '../../icons/svg/ontario-icon-sentiment-1.svg'}}" download="ontario-icon-sentiment-1.svg">SVG</a>
|{{{render '@icons-secondary--ontario-icon-sentiment-2' }}} | ontario-icon-sentiment-2| <a download href="{{path '../../icons/png/ontario-icon-sentiment-2.png'}}">PNG</a> , <a target="_blank" href="{{path '../../icons/svg/ontario-icon-sentiment-2.svg'}}" download="ontario-icon-sentiment-2.svg">SVG</a>
|{{{render '@icons-secondary--ontario-icon-sentiment-3' }}} | ontario-icon-sentiment-3| <a download href="{{path '../../icons/png/ontario-icon-sentiment-3.png'}}">PNG</a> , <a target="_blank" href="{{path '../../icons/svg/ontario-icon-sentiment-3.svg'}}" download="ontario-icon-sentiment-3.svg">SVG</a>
|{{{render '@icons-secondary--ontario-icon-sentiment-4' }}} | ontario-icon-sentiment-4| <a download href="{{path '../../icons/png/ontario-icon-sentiment-4.png'}}">PNG</a> , <a target="_blank" href="{{path '../../icons/svg/ontario-icon-sentiment-4.svg'}}" download="ontario-icon-sentiment-4.svg">SVG</a>
|{{{render '@icons-secondary--ontario-icon-sentiment-5' }}} | ontario-icon-sentiment-5| <a download href="{{path '../../icons/png/ontario-icon-sentiment-5.png'}}">PNG</a> , <a target="_blank" href="{{path '../../icons/svg/ontario-icon-sentiment-5.svg'}}" download="ontario-icon-sentiment-5.svg">SVG</a>
|{{{render '@icons-secondary--ontario-icon-vote-dislike' }}} | ontario-icon-vote-dislike| <a download href="{{path '../../icons/png/ontario-icon-vote-dislike.png'}}">PNG</a> , <a target="_blank" href="{{path '../../icons/svg/ontario-icon-vote-dislike.svg'}}" download="ontario-icon-vote-dislike.svg">SVG</a>
|{{{render '@icons-secondary--ontario-icon-vote-like' }}} | ontario-icon-vote-like| <a download href="{{path '../../icons/png/ontario-icon-vote-like.png'}}">PNG</a> , <a target="_blank" href="{{path '../../icons/svg/ontario-icon-vote-like.svg'}}" download="ontario-icon-vote-like.svg">SVG</a>

</div>

<hr>

## <a name="how-to-use-secondary-icons"></a>Comment utiliser les icônes secondaires 

Copiez et collez le code SVG pour le fichier d’icônes principal. Insérez-le dans votre code. Veuillez noter que vous devrez inclure le polyfill pour que les icônes s’affichent convenablement sur IE11.

Téléchargez le magasin SVG des icônes secondaires à partir d’un fichier autohébergé ou de notre CDN. Veuillez noter que vous devrez inclure le polyfill pour que les icônes s’affichent convenablement sur IE11.

1. Vous pouvez télécharger les icônes de deux façons&nbsp;:

    * Téléchargez le fichier des icônes secondaires et hébergez le fichier sur votre serveur ou site Web<br><a download href="{{path '../../icons/ontario-icons-secondary.svg'}}">Téléchargez le magasin d’icônes secondaires SVG ici</a>
    
    * Utilisez notre fichier hébergé <br> https://designsystem.ontario.ca/icons/ontario-icons-secondary.svg

2. Ajoutez le <a download href="{{path '../../scripts/svgxuse.js'}}">polyfill</a> qui fixe les SVG sur IE et d’autres navigateurs plus anciens. 
<br>{{{render '@inline-code--icons-secondary-setup' }}}

3.	Utilisez le SVG en HTML dans votre code
    * Si ontario-icons-secondary.svg est autohébergé, utilisez le code ci dessous et ajustez xlink:href au bon chemin d’accès&nbsp;:
    <br>{{{render '@inline-code--icons-secondary' }}}

    * Pour utiliser notre fichier hébergé SVG d’icônes secondaires, établissez le xlink:href, par exemple comme suit&nbsp;:  ``` https://designsystem.ontario.ca/icons/ontario-icons-secondary.svg#ontario-icon-account ```

4. Ajoutez dans le fichier CSS de votre projet l’icône ontario-icon en forme CSS que vous trouverez sous l’onglet SCSS ou CSS compilé.  

<hr>

## Caractéristiques techniques (icônes primaires et secondaires)

<div class="fractal-table-scroll">

|Type de fichier |SVG |
| -----------| -----|
|Taille|Minimum `16 px`<br>Maximum H1 (`40 px` pour ordinateur, `32 px` pour appareils mobiles)|
|Taille de la correspondance|Si l’icône est cliquable, la taille de la zone de correspondance doit être d’au moins `48 px` sur `48 px` (voir Cases d’option pour un exemple où la taille de la correspondance est supérieure à celle de l’élément).<br><br>Si l’icône est une composante autonome, sa zone de correspondance doit être de `48 px` sur `48 px`. Si elle est cliquable et alignée avec le texte, elle doit avoir la même taille que la police.|
|Couleur|Noir&nbsp;: `#1A1A1A`<br>Blanc&nbsp;: `#FFFFFF`<br>Gris&nbsp;: `#666666`<br>Bleu (s’il s’agit d’un hyperlien)&nbsp;:<br> <ul><li>Régulier&nbsp;:  `#0066CC`</li><li>Effet de survol&nbsp;:  `#004E99`</li><li>Visité&nbsp;: `#551A8B`</li></ul><br>Exceptions&nbsp;: certaines icônes viennent avec des couleurs déjà incorporées. Ne remplacez pas les couleurs des icônes qui sont déjà incorporées. Exemples&nbsp;:<br><ul><li>icônes d’alerte (rouge, vert et jaune)</li><li>icônes de Visa, Mastercard et Interac</li></ul>

</div>

<hr>

## Aidez-nous à améliorer cette page
Si vous avez d’autres suggestions, des conseils ou des questions sur les icônes, [l’équipe du système de conception]({{path '../../docs/give-feedback.html'}}) serait heureuse de les connaître.
