---
title: Ontario Government design principles
label: Design principles
---

<p class="ontario-lead-statement">Use these principles with the design system and <a href="https://www.ontario.ca/page/digital-service-standard">Digital Service Standard (<abbr>DSS</abbr>)</a> to help you make decisions when designing services for Ontarians.</p>

<hr class="dark">

## The purpose of these principles

All elements in Ontario’s Design System meet these design principles.

While the [design system team]({{path '../../docs/give-feedback.html'}}) is continually updating, improving and adding to the system, we recognize that your project may have design needs that aren’t covered.

If an element you need:

* is **in** the design system, but doesn’t have the level of detail you need, use its “guiding principle” (found at the top of its entry) to guide your work
* **is not in** the design system, use the following principles to guide your work:

### 1. Put the user first

Service design starts with defining the problem that needs to be solved. Talk to and test with real users who are experiencing the problem and ensure that their needs come first in your design &ndash; don’t let back-end issues dictate a front-end design that isn’t intuitive for users.

See [<abbr title="Digital Service Standard">DSS</abbr> principle #1](https://www.ontario.ca/page/digital-service-standard#section-1) for more on understanding users and their needs.

### 2. Only include elements that have a purpose

Every element in a user’s experience should have a functional purpose. Don’t add anything that doesn’t explicitly help the user complete their task. In some cases, this will mean sacrificing beauty and flair for purpose &ndash; and that’s okay!

### 3. Be consistent

Using design system elements for their identified purpose will automatically help keep your designs consistent. Consistency helps users feel:
* confident that they’re using a legitimate Ontario government service
* comfortable, because they’ll be able to anticipate how our services will work

While consistency is a very important design principle, keeping the user’s experience as effortless as possible always comes first. So if ever you need to introduce a little inconsistency to your design to give the user a smoother experience, that’s okay!

### 4. Design for everyone

All Ontarians deserve easy-to-use government services. Make sure your design works for everyone &ndash; including people who:
-   use assistive devices such as text readers, alternative input devices or screen magnifiers
-   prefer to, or can only, access the internet on a mobile device
    -   design your service so that it works for the smallest screen first, then expand it for larger screens
-   have slow or unreliable internet services, computers or devices
-   may have trouble reading or understanding English or French

[Learn more about designing for inclusivity](https://www.ontario.ca/page/inclusive-design-toolkit)

### 5. Start simple

Simple designs are easier to change than complex ones. Create and test the simplest version of your service first, to keep it flexible enough to change or adapt to user needs as you add new functionality and design elements. 

### 6. Continually test and improve &ndash; even after launch

Technology and user needs and behaviours change over time. Keep your product relevant and useful by setting up a schedule and process to continually test and improve it, even after you’ve launched. 
